@@ -310,9 +310,11 @@ static gchar* create_end_message(gint score) {
 
 static gboolean restore_box_image(gpointer data) {
 	struct game_data *d = (struct game_data *)data;
-	gint n = d->s->last;
-	set_box_image(d, n, d->s->b[n]);
-	d->s->active = TRUE;
+	if (d->s->score > 0) {	// Cannot restore if game not started
+		gint n = d->s->last;
+		set_box_image(d, n, d->s->b[n]);
+		d->s->active = TRUE;
+	}
 	return FALSE; // no repeat		
 }
 
