@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with 100 Boxes.  If not, see <http://www.gnu.org/licenses/>.
+ * along with 100 Boxes. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #define OSSO_SERVICE "org.maemo.garage.project100boxes"
-#define VERSION "0.5.0"
 #define HEIGHT 480
 #define WIDTH 800
 #define PADDING 35
@@ -29,6 +28,11 @@
 #define SCORE_SRC "ma"
 #define MAX_QUERY_LENGTH 27 // n=max_12_chars&s=100&src=ma
 #define POST_URL "http://fgs.altervista.org/100bwhss.php"
+#define SOUND_START "/usr/share/sounds/100boxes/start.mp3"
+#define SOUND_CLICK "/usr/share/sounds/100boxes/click.mp3"
+#define SOUND_WIN "/usr/share/sounds/100boxes/win.mp3"
+#define SOUND_LOSE "/usr/share/sounds/100boxes/lose.mp3"
+#define SOUND_ERROR "/usr/share/sounds/100boxes/error.mp3"
 
 struct state {
 	gboolean active;
